==> input_calculator-1.0.2.tar.gz: lib/src/calculator_text_form_field.dart <==
import 'package:flutter/material.dart';

import 'base_text_field.dart';

class CalculatorTextFormField extends StatefulWidget with BaseTextField {
  CalculatorTextFormField({
    Key key,
    this.title,
    this.initialValue = 0.0,
    this.boxDecoration,
    this.appBarBackgroundColor,
    this.operatorButtonColor: Colors.amber,
    this.operatorTextButtonColor: Colors.white,
    this.normalButtonColor: Colors.white,
    this.normalTextButtonColor: Colors.grey,
    this.doneButtonColor: Colors.blue,
    this.doneTextButtonColor: Colors.white,
    this.onSubmitted,
    this.inputDecoration = const InputDecoration(),
    this.style,
    this.strutStyle,
    this.textAlign = TextAlign.start,
    this.validator,
  }) : super(key: key);

  final String title;
  final double initialValue;
  final BoxDecoration boxDecoration;
  final Color appBarBackgroundColor;
  final Color operatorButtonColor;
  final Color operatorTextButtonColor;
  final Color normalButtonColor;
  final Color normalTextButtonColor;
  final Color doneButtonColor;
  final Color doneTextButtonColor;
  final ValueChanged<double> onSubmitted;
  final InputDecoration inputDecoration;
  final TextStyle style;
  final StrutStyle strutStyle;
  final TextAlign textAlign;
  final FormFieldValidator<String> validator;

  @override
  _CalculatorTextFormFieldState createState() =>
      _CalculatorTextFormFieldState();
}

class _CalculatorTextFormFieldState extends State<CalculatorTextFormField> {
  final inputController = TextEditingController();

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      controller: inputController,
      readOnly: true,
      style: widget.style,
      strutStyle: widget.strutStyle,
      textAlign: widget.textAlign,
      validator: widget.validator,
      onTap: () async {
        final resutl = await widget.showInputCalculator(context);
        setState(() {
          inputController.text = '${resutl ?? 0.0}';

          if (widget.onSubmitted != null) widget.onSubmitted(resutl);
        });
      },
    );
  }
}

==> input_calculator-2.0.0.tar.gz: lib/src/calculator_text_form_field.dart <==
import 'package:flutter/material.dart';

import 'base_text_field.dart';
import 'themes.dart';

class CalculatorTextFormField extends StatefulWidget with BaseTextField {
  CalculatorTextFormField({
    Key? key,
    this.title,
    this.initialValue = 0.0,
    this.boxDecoration,
    this.appBarBackgroundColor,
    this.operatorButtonColor: Colors.amber,
    this.operatorTextButtonColor: Colors.white,
    this.normalButtonColor: Colors.white,
    this.normalTextButtonColor: Colors.grey,
    this.doneButtonColor: Colors.blue,
    this.doneTextButtonColor: Colors.white,
    this.onSubmitted,
    this.inputDecoration = const InputDecoration(),
    this.style,
    this.strutStyle,
    this.textAlign = TextAlign.start,
    this.validator,
    this.valueFormat,
    this.allowNegativeResult = true,
    this.theme = CalculatorThemes.curve,
  }) : super(key: key);

  final String? title;
  final double initialValue;
  final BoxDecoration? boxDecoration;
  final Color? appBarBackgroundColor;
  final Color operatorButtonColor;
  final Color operatorTextButtonColor;
  final Color normalButtonColor;
  final Color normalTextButtonColor;
  final Color doneButtonColor;
  final Color doneTextButtonColor;
  final ValueChanged<double?>? onSubmitted;
  final InputDecoration inputDecoration;
  final TextStyle? style;
  final StrutStyle? strutStyle;
  final TextAlign textAlign;
  final FormFieldValidator<String>? validator;
  final ValueFormat<double?>? valueFormat;
  final bool allowNegativeResult;
  final CalculatorThemes theme;

  @override
  _CalculatorTextFormFieldState createState() =>
      _CalculatorTextFormFieldState();
}

class _CalculatorTextFormFieldState extends State<CalculatorTextFormField> {
  final inputController = TextEditingController();

  @override
  void initState() {
    super.initState();

    setValue(widget.initialValue);
  }

  void setValue(value) {
    inputController.text =
        widget.valueFormat != null ? widget.valueFormat!(value) : '$value';
  }

  @override
  Widget build(BuildContext context) {
    return TextFormField(
      controller: inputController,
      readOnly: true,
      style: widget.style,
      strutStyle: widget.strutStyle,
      textAlign: widget.textAlign,
      validator: widget.validator,
      decoration: widget.inputDecoration,
      onTap: () async {
        final result = await widget.showInputCalculator(context);
        setState(() {
          setValue(result);

          if (widget.onSubmitted != null) widget.onSubmitted!(result);
        });
      },
    );
  }
}
